@@ -1,13 +1,15 @@
 from .actor import Actor
 from .asyncio_monitor import AsyncioMonitor
 from .automator import Automator
+from .backup import Backup
 from .camera_projector import CameraProjector
 from .detector import Detector
+from .detector_simulator import DetectorSimulator, SimulatedObject
 from .garbage_collector import GarbageCollector
 from .lizard import Lizard
 from .network_monitor import NetworkMonitor, NetworkStats
 from .odometer import Odometer
+from .path_planner import PathPlanner
 from .steerer import Steerer
 from .usb_camera_capture import UsbCameraCapture
 from .usb_camera_simulator import UsbCameraSimulator
-from .backup import Backup
