@@ -5,7 +5,6 @@ from typing import Any, Optional
 
 import cv2
 import rosys
-from rosys.world.camera import Camera
 
 from .. import event
 from ..world import Image, ImageSize, UsbCamera
@@ -22,13 +21,23 @@ class Device:
     exposure: Optional[float] = None
 
 
+def process_image(image, rotation: rosys.world.ImageRotation) -> bytes:
+    if rotation == rosys.world.ImageRotation.LEFT:
+        image = cv2.rotate(image, cv2.ROTATE_90_COUNTERCLOCKWISE)
+    elif rotation == rosys.world.ImageRotation.RIGHT:
+        image = cv2.rotate(image, cv2.ROTATE_90_CLOCKWISE)
+    elif rotation == rosys.world.ImageRotation.UPSIDE_DOWN:
+        image = cv2.rotate(image, cv2.ROTATE_180)
+    return cv2.imencode('.jpg', image)[1].tobytes()
+
+
 class UsbCameraCapture(Actor):
-    interval: float = 0.30
+    interval: float = 0.3
 
     def __init__(self):
         super().__init__()
         self.devices: dict[str, Device] = {}
-        self.last_scan = None
+        self.last_scan: Optional[float] = None
 
     async def step(self):
         await super().step()
@@ -37,22 +46,30 @@ class UsbCameraCapture(Actor):
             if not camera.capture or not camera.connected:
                 continue
             try:
-                bytes = await rosys.run.io_bound(self.capture_image, uid)
-                camera.images.append(Image(camera_id=uid, data=bytes, time=self.world.time, size=camera.resolution))
+                image = await rosys.run.io_bound(self.capture_image, uid)
+                if image is None:
+                    self.disconnect(uid)
+                    continue
+                bytes = await rosys.run.cpu_bound(process_image, image, camera.rotation)
+                size = camera.resolution or ImageSize(width=800, height=600)
+                camera.images.append(Image(camera_id=uid, data=bytes, time=self.world.time, size=size))
             except:
-                self.log.exception(f'could not capture image from {uid}; disconnecting')
-                camera.connected = False
-                del self.devices[camera.id]
+                self.log.exception(
+                    f'could not capture image from {uid}; disconnecting device /dev/video{self.devices[uid].video_id}')
+                self.disconnect(uid)
         self.purge_old_images()
 
-    def capture_image(self, id) -> bytes:
-        camera = self.world.usb_cameras[id]
+    def capture_image(self, id) -> Any:
         capture = self.devices[id].capture
-        if camera.resolution:
-            capture.set(cv2.CAP_PROP_FRAME_WIDTH, camera.resolution.width)
-            capture.set(cv2.CAP_PROP_FRAME_HEIGHT, camera.resolution.height)
         _, image = capture.read()
-        return cv2.imencode('.jpg', image)[1].tobytes()
+        return image
+
+    def disconnect(self, uid: str):
+        self.log.info(f'disconnecting {uid}')
+        camera = self.world.usb_cameras[uid]
+        camera.connected = False
+        self.devices[camera.id].capture.release()
+        del self.devices[camera.id]
 
     def purge_old_images(self):
         for camera in self.world.usb_cameras.values():
@@ -95,8 +112,11 @@ class UsbCameraCapture(Actor):
     def get_capture_device(self, index: int):
         try:
             capture = cv2.VideoCapture(index)
-            if capture is None or not capture.isOpened():
-                self.log.error(f'{index} is unavailable device')
+            if capture is None:
+                self.log.error(f'video device {index} is unavailable')
+            elif not capture.isOpened():
+                self.log.error(f'video device {index} can not be opened')
+                capture.release()
             else:
                 return capture
         except:
@@ -118,15 +138,23 @@ class UsbCameraCapture(Actor):
         size = re.search('Width/Height.*: (\d*)/(\d*)', output)
         device.resolution = ImageSize(width=int(size.group(1)), height=int(size.group(2)))
         camera = self.world.usb_cameras[device.uid]
-        # TODO read exposure from output and update it correctly
-    #     if device.exposure != camera.brightness:
-    #         await self.update_exposure(device)
+        if camera.resolution and camera.resolution != device.resolution:
+            self.log.info(f'updating resolution of {camera.id} from {device.resolution} to {camera.resolution}')
+            await rosys.run.io_bound(UsbCameraCapture.update_resolution, device, camera.resolution)
+            # TODO read exposure from output and update it correctly
+            #     if device.exposure != camera.brightness:
+            #         await self.update_exposure(device)
 
-    # async def update_exposure(self, device: Device):
-    #     exposure = self.world.usb_cameras[device.uid].exposure
-    #     # TODO if expousre is None, set auto exposure
-    #     await self.run_v4l(device, '--set-ctrl=brightness=0', '--set-ctrl=exposure_auto=1', f'--set-ctrl=exposure_absolute={exposure}')
-    #     self.log.info(f'using new exposure {exposure}')
+            # async def update_exposure(self, device: Device):
+            #     exposure = self.world.usb_cameras[device.uid].exposure
+            #     # TODO if expousre is None, set auto exposure
+            #     await self.run_v4l(device, '--set-ctrl=brightness=0', '--set-ctrl=exposure_auto=1', f'--set-ctrl=exposure_absolute={exposure}')
+            #     self.log.info(f'using new exposure {exposure}')
+
+    @staticmethod
+    def update_resolution(device: Device, size: ImageSize):
+        device.capture.set(cv2.CAP_PROP_FRAME_WIDTH, size.width)
+        device.capture.set(cv2.CAP_PROP_FRAME_HEIGHT, size.height)
 
     async def run_v4l(self, device: Device, *args):
         cmd = ['v4l2-ctl', '-d', str(device.video_id)]
