@@ -1,23 +1,40 @@
 from typing import Optional
-import asyncio
 import os
 import serial
+import logging
 from .communication import Communication
 
+log = logging.getLogger('rosys.hardware.serial_communication')
+
 
 class SerialCommunication(Communication):
-    device_path: str = '/dev/esp'
     baudrate: int = 115200
 
     def __init__(self):
         super().__init__()
+        self.device_path = SerialCommunication.get_device_path()
+        if self.device_path is None:
+            raise Exception('No serial port found')
         self.log.debug(f'connecting serial on {self.device_path} with baudrate {self.baudrate}')
         self.serial = serial.Serial(self.device_path, self.baudrate)
         self.buffer = ''
 
     @classmethod
     def is_possible(cls) -> bool:
-        return os.path.exists(cls.device_path) and os.stat(cls.device_path).st_gid > 0
+        return cls.get_device_path() is not None
+
+    @classmethod
+    def get_device_path(cls) -> Optional[str]:
+        device_paths = [
+            '/dev/ttyTHS1',
+            '/dev/ttyUSB0',
+            '/dev/tty.SLAB_USBtoUART',
+            '/dev/serial/by-id/usb-Silicon_Labs_CP2102_USB_to_UART_Bridge_Controller_0001-if00-port0',
+            '/dev/esp',
+        ]
+        for device_path in device_paths:
+            if os.path.exists(device_path) and os.stat(device_path).st_gid > 0:
+                return device_path
 
     def connect(self):
         if not self.serial.isOpen():
@@ -41,4 +58,3 @@ class SerialCommunication(Communication):
     async def send_async(self, line: str):
         self.serial.write(f'{line}\n'.encode())
         self.log.debug(f'send: {line}')
-        await asyncio.sleep(0)
