@@ -6,6 +6,8 @@ from aenum import Enum, auto
 from typing import Awaitable, Callable, Union
 import logging
 import weakref
+import functools
+
 
 tasks: list[Task] = []
 listeners = collections.defaultdict(set)
@@ -49,7 +51,7 @@ def unregister(event: Id, listener: Union[Callable, Awaitable]):
         if registered() == listener:
             marked.append(registered)
     [listeners[event].remove(m) for m in marked]
-    log.debug(f'unregistered {listener} from {event}')
+    #log.debug(f'unregistered {listener} from {event}')
 
 
 async def call(event: Id, *args):
@@ -58,19 +60,20 @@ async def call(event: Id, *args):
     #     log.info(f'calling {event=}')
     for listener in list(listeners.get(event, {})):
         try:
-            if event != Id.NEW_MACHINE_DATA:
-                log.debug(f'emitting {event} with {listener}')
+            # if event != Id.NEW_MACHINE_DATA:
+            #     log.debug(f'emitting {event} with {listener}')
             if hasattr(listener, '__name__') and listener.__name__ == '<lambda>':
                 listener(*args)
                 continue
-            if listener() is None:
+            callback = listener()
+            if callback is None:
                 listeners[event].remove(listener)
                 log.debug(f'unregistered {listener} from {event}')
                 continue
-            if inspect.iscoroutinefunction(listener()):
-                await listener()(*args)
+            if iscoroutinefunction(listener):
+                await callback(*args)
             else:
-                listener()(*args)
+                callback(*args)
         except:
             log.exception(f'could not call {listener=} for {event=}')
 
@@ -83,18 +86,24 @@ def emit(event: Id, *args):
     #     log.info(f'emitting {event=}')
     loop = asyncio.get_event_loop()
     for listener in list(listeners.get(event, {})):
-        if event != Id.ROBOT_MOVED:
-            log.debug(f'emitting {event} with {listener}')
+        # if event != Id.ROBOT_MOVED:
+        #     log.debug(f'emitting {event} with {listener}')
         try:
             if hasattr(listener, '__name__') and listener.__name__ == '<lambda>':
                 listener(*args)
                 continue
-            if listener() is None:
+            callback = listener()
+            if callback is None:
                 unregister(event, listener)
                 continue
-            if inspect.iscoroutinefunction(listener()):
-                tasks.append(loop.create_task(listener()(*args), name=f'handle {event=}'))
+            if iscoroutinefunction(listener):
+                tasks.append(loop.create_task(callback(*args), name=f'handle {event.name}'))
             else:
-                listener()(*args)
+                callback(*args)
         except:
             log.exception(f'could not call {listener=} for {event=}')
+
+
+@functools.lru_cache(maxsize=100)
+def iscoroutinefunction(listener):
+    return inspect.iscoroutinefunction(listener())
