@@ -1,5 +1,6 @@
-import logging
 import abc
+import logging
+
 from ..world import World
 
 
@@ -34,3 +35,11 @@ class Hardware(abc.ABC):
     async def update(self):
         '''Called by actors to update the world'''
         return
+
+    @property
+    def is_simulation(self) -> bool:
+        return True
+
+    @property
+    def is_real(self) -> bool:
+        return not self.is_simulation
