@@ -10,7 +10,8 @@ from .actors import (Actor, AsyncioMonitor, Automator, Backup, CameraProjector,
                      Detector, DetectorSimulator, GarbageCollector, Lizard,
                      NetworkMonitor, Odometer, PathPlanner, Steerer,
                      UsbCameraCapture, UsbCameraSimulator)
-from .hardware import CommunicatingHardware, Hardware, SimulatedHardware
+from .communication import CommunicationFactory
+from .hardware import Hardware, RobotBrain, SimulatedHardware
 from .world import World
 
 
@@ -27,10 +28,10 @@ class Runtime:
         if not is_test:
             self.persistence = persistence or Persistence(self.world)
             self.persistence.restore()
-        self.hardware = hardware or SimulatedHardware(self.world)
+
+        self.hardware = hardware or self.create_hardware()
         if is_test:
-            assert isinstance(self.hardware, SimulatedHardware), \
-                'real hardware must not be used in tests'
+            assert self.hardware.is_simulation, 'real hardware must not be used in tests'
         self.lizard = Lizard(self.hardware)
         self.odometer = Odometer()
         self.steerer = Steerer(self.hardware)
@@ -38,6 +39,7 @@ class Runtime:
         self.camera_projector = CameraProjector()
         self.asyncio_monitor = AsyncioMonitor()
         self.detector: Optional[Detector] = None  # NOTE can be set by runtime.with_detector()
+        self.usb_camera_simulator: Optional[UsbCameraSimulator] = None  # NOTE can be set by runtime.with_usb_cameras()
         self.actors = [
             self.camera_projector,
             self.lizard,
@@ -53,6 +55,13 @@ class Runtime:
             self.with_actors(Backup(self.persistence))
         self.path_planner: Optional[PathPlanner] = None
 
+    def create_hardware(self):
+        communication = CommunicationFactory.create()
+        if communication is not None:
+            return RobotBrain(self.world, communication)
+        else:
+            return SimulatedHardware(self.world)
+
     def with_actors(self, *actors: list[Actor]) -> Runtime:
         '''Adds list of additional actors to runtime.'''
         self.actors += actors
@@ -67,12 +76,12 @@ class Runtime:
             self.with_actors(self.usb_camera_simulator)
         return self
 
-    def with_detector(self, real: Detector = Detector(), simulation: DetectorSimulator = DetectorSimulator()) -> Runtime:
+    def with_detector(self, real: Optional[Detector] = None, simulation: Optional[DetectorSimulator] = None) -> Runtime:
         '''Adds detector to runtime.'''
-        if isinstance(self.hardware, CommunicatingHardware) and not is_test:
-            self.detector = real
+        if self.hardware.is_real and not is_test:
+            self.detector = real or Detector()
         else:
-            self.detector = simulation
+            self.detector = simulation or DetectorSimulator()
         self.with_actors(self.detector)
         return self
 
@@ -82,12 +91,6 @@ class Runtime:
         self.with_actors(self.path_planner)
         return self
 
-    def get_actor(self, type_: Type[Actor]) -> Actor:
-        for a in self.actors():
-            if isinstance(a, type_):
-                return a
-        return None
-
     async def startup(self):
         if self.tasks:
             raise Exception('should be only executed once')
@@ -108,6 +111,7 @@ class Runtime:
             await asyncio.sleep(1)  # NOTE we wait for RoSys to start up before analyzing async debugging
         self.activate_async_debugging()
         self.log.debug('startup completed')
+        self.world.start_time = self.world.time
 
     async def shutdown(self):
         try:
@@ -146,7 +150,7 @@ class Runtime:
             except (CancelledError, GeneratorExit):
                 return
 
-    def get_actor(self, _type: Type):
+    def get_actor(self, _type: Type[Actor]) -> Actor:
         return next((a for a in self.actors if type(a) is _type), None)
 
     def store_notification(self, message: str):
