@@ -1,8 +1,8 @@
-from .configure import configure
-
 from .area_object import AreaObject as area_object
 from .asyncio_page import AsyncioPage as asyncio_page
 from .automation_controls import AutomationControls as automation_controls
+from .camera_objects import CameraObjects as camera_objects
+from .configure import configure
 from .cpu_usage import CpuUsage as cpu_usage
 from .joystick import Joystick as joystick
 from .keyboard_control import KeyboardControl as keyboard_control
@@ -14,4 +14,5 @@ from .path_object import PathObject as path_object
 from .profiler import create_profiler
 from .pyloot_page import PylootPage as pyloot_page
 from .robot_object import RobotObject as robot_object
+from .settings import update_interval
 from .wifi import create_wifi
