@@ -1,5 +1,8 @@
-from typing import Awaitable, Optional
+import inspect
+from typing import Awaitable, Callable, Optional, Union
+
 from nicegui.ui import Ui
+
 from .. import Runtime
 from .settings import update_interval
 
@@ -8,9 +11,16 @@ class AutomationControls:
     ui: Ui
     runtime: Runtime
 
-    def __init__(self, default_automation: Optional[Awaitable] = None) -> None:
+    def __init__(self,
+                 default_automation: Optional[Awaitable] = None,
+                 can_start: Optional[Union[Callable[[], bool], Awaitable[bool]]] = None) -> None:
 
-        def start():
+        async def start():
+            if inspect.iscoroutinefunction(can_start):
+                if not await can_start():
+                    return
+            elif can_start is not None and not can_start():
+                return
             self.runtime.automator.start(default_automation())
 
         def pause():
