@@ -1,6 +1,7 @@
-from nicegui.ui import Ui
 from nicegui.elements.chart import Chart
+from nicegui.ui import Ui
 from rosys.actors import Lizard
+
 from .settings import update_interval
 
 
@@ -25,8 +26,9 @@ class LizardStats(Chart):
         })
         self.ui.timer(update_interval, self.update)
 
-    def update(self):
+    def update(self) -> bool:
         self.options.series[0].data.append(max(self.lizard.responsiveness_stats or [0]) * 1000)
         self.options.series[1].data.append(max(self.lizard.update_stats or [0]) * 1000)
         self.options.series[2].data.append(max(self.lizard.processing_stats or [0]) * 1000)
         [s.data.pop(0) for s in self.options.series if len(s.data) > 20]
+        return False  # NOTE: avoid JustPy page_update
