@@ -23,7 +23,7 @@ class ImageSize(BaseModel):
 class Image(BaseModel):
     camera_id: str
     size: ImageSize
-    time: float  # World time of recording
+    time: float  # world time of recording
     data: Optional[bytes] = None
     detections: Optional[Detections] = None
 
@@ -36,7 +36,7 @@ class Image(BaseModel):
         return f'{self.camera_id}/{self.time}'
 
     @staticmethod
-    def create_placeholder(text: str, time: float = None, camera_id: str = None) -> Image:
+    def create_placeholder(text: str, time: Optional[float] = None, camera_id: Optional[str] = None) -> Image:
         img = PIL.Image.new('RGB', (260, 200), color=(73, 109, 137))
         d = PIL.ImageDraw.Draw(img)
         d.text((img.width/2-len(text)*3, img.height/2-5), text, fill=(255, 255, 255))
@@ -45,7 +45,7 @@ class Image(BaseModel):
         image = Image(
             camera_id=camera_id or 'no_cam_id',
             time=time or 0,
-            size=ImageSize(width=img.width, height=img.height)
+            size=ImageSize(width=img.width, height=img.height),
         )
         image.data = bytesio.getvalue()
         return image
