@@ -2,6 +2,8 @@ from __future__ import annotations
 from pydantic import BaseModel
 import math
 
+from .point import Point
+
 
 class Point3d(BaseModel):
     x: float
@@ -15,5 +17,8 @@ class Point3d(BaseModel):
     def distance(self, other: Point3d):
         return math.sqrt((other.x - self.x)**2 + (other.y - self.y)**2 + (other.z - self.z)**2)
 
+    def projection(self) -> Point:
+        return Point(x=self.x, y=self.y)
+
     def __str__(self) -> str:
-        return f'Point({round(self.x, 2)}, {round(self.y, 2)}, {round(self.z, 2)})'
+        return f'Point3d({round(self.x, 2)}, {round(self.y, 2)}, {round(self.z, 2)})'
